#!/usr/bin/env python3

import sys
from pathlib import Path

pyng_home = Path(__file__).resolve().parent.parent
sys.path.insert(0, str(pyng_home.joinpath('lib')))

from twisted.internet import reactor

from pyng import load_conf
from pyng.master import PyngMaster


if len(sys.argv) > 1:
    checks = load_conf(*[f for f in sys.argv[1:] if f.endswith('.conf')])
else:
    checks = load_conf(pyng_home.joinpath('conf', 'checks.conf'))


# there are some adjustable options below
reactor.callWhenRunning(
    PyngMaster(
        checks=checks,
        # adjust number of workers to process checks, results and alerts
        # number of workers corresponds to number of mentioned events being
        # processed concurrently
        check_workers=20,
        result_workers=10,
        alert_workers=5,
        # port for web listener used to receive PUSH updates (/push/<...>) and to make
        # available overall status (/stats) and check information (/check/<...>)
        web_port=31337,
        # by default web listener listens on localhost (::1 and 127.0.0.1),
        # uncomment line below to listen on all IPv6 and IPv4 interfaces
        # web_interface='::,0.0.0.0',
    ).startService
)
reactor.run()
