#!/usr/bin/env python3

import sys
from pathlib import Path

pyng_home = Path(__file__).resolve().parent.parent
sys.path.insert(0, str(pyng_home.joinpath('lib')))

from twisted.internet import reactor

import pyng
from pyng.master import PyngMaster


if len(sys.argv) > 1:
    checks = pyng.load_conf(*sys.argv[1:])
else:
    checks = pyng.load_conf(pyng_home.joinpath('conf', 'checks.conf'))


results = []


def on_result(check, res):
    results.append(res)

    print('=' * 99)
    print(check.info())
    print('CMD:', ' '.join(check.cmd))
    print('=' * 99)

    up = True if check.check(res) else False
    print('+++' if up else '---', res.info())

    if check.type == 'DNS' and check.dnssec and not check.trace:
        recs, sigs = check.recsig(res)
        print('* recs *')
        print(recs)
        print('* sigs *')
        print(sigs)

    if res.output:
        print('* output *')
        print('\n'.join([f'. {x}'[0:98] for x in res.output[:20]]))

        if callable(check.result_filter):
            print('* filtered *')
            print('\n'.join(check.result_filter(res.output)))

        if check.last_result:
            changed, diff = check.diff(res, check.last_result)
            if changed:
                print('* changes *')
                print('\n'.join(diff))
            else:
                print('* no changes *')

    if res.errput:
        print('* errput *')
        print('\n'.join([f'! {x}' for x in res.errput]))

    print()
    if checks:
        pm.addCheck(checks.pop(0))
    else:
        print('***', len(results), 'checks ***')
        reactor.callWhenRunning(reactor.stop)


for check in checks:
    check.interval = 0
    check.silent = True
    check.on_result = on_result

pm = PyngMaster([], check_workers=1, result_workers=1)
reactor.callWhenRunning(pm.startService)
reactor.callWhenRunning(pm.addCheck, checks.pop(0))

reactor.run()
